@@ -2,7 +2,7 @@
 ** HyperlinkManager.cpp                                                 **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2025 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -55,7 +55,7 @@ void HyperlinkManager::addHrefAnchor (const string &uri) {
 }
 
 
-void HyperlinkManager::addNameAchor (const string &name, int pageno) {
+void HyperlinkManager::addNameAnchor (const string &name, int pageno) {
 	if (name.empty())
 		return;
 	auto it = _namedAnchors.find(name);
