@@ -2,7 +2,7 @@
 ** PsSpecialHandler.cpp                                                 **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2025 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -142,7 +142,7 @@ void PsSpecialHandler::moveToDVIPos () {
 }
 
 
-/** Executes a PS snippet and optionally synchronizes the DVI cursor position
+/** Executes a PS fragment and optionally synchronizes the DVI cursor position
  *  with the current PS point.
  *  @param[in] is  stream to read the PS code from
  *  @param[in] updatePos if true, move the DVI drawing position to the current PS point */
@@ -393,7 +393,7 @@ static string image_base_path (const SpecialActions &actions) {
  *  @param[in] bbox bounding box of the image
  *  @param[in] clip if true, the image is clipped to its bounding box
  *  @return pointer to the element or nullptr if there's no image data */
-PsSpecialHandler::ImageNode PsSpecialHandler::createImageNode (FileType type, const string &fname, int pageno, BoundingBox bbox, bool clip) {
+PsSpecialHandler::ImageNode PsSpecialHandler::createImageNode (FileType type, const string &fname, int pageno, const BoundingBox &bbox, bool clip) {
 	ImageNode imgnode;
 	string pathstr;
 	if (const char *path = FileFinder::instance().lookup(fname, false))
@@ -412,7 +412,7 @@ PsSpecialHandler::ImageNode PsSpecialHandler::createImageNode (FileType type, co
 }
 
 
-PsSpecialHandler::ImageNode PsSpecialHandler::createBitmapNode (const string &fname, const string &path, int pageno, BoundingBox bbox) {
+PsSpecialHandler::ImageNode PsSpecialHandler::createBitmapNode (const string &fname, const string &path, int pageno, const BoundingBox &bbox) const {
 	ImageNode imgnode(util::make_unique<SVGElement>("image"));
 	imgnode.element->addAttribute("x", 0);
 	imgnode.element->addAttribute("y", 0);
@@ -434,7 +434,7 @@ PsSpecialHandler::ImageNode PsSpecialHandler::createBitmapNode (const string &fn
 }
 
 
-PsSpecialHandler::ImageNode PsSpecialHandler::createPSNode (const string &fname, const string &path, int pageno, BoundingBox bbox, bool clip) {
+PsSpecialHandler::ImageNode PsSpecialHandler::createPSNode (const string &fname, const string &path, int pageno, const BoundingBox &bbox, bool clip) {
 	ImageNode imgnode(util::make_unique<SVGElement>("g")); // put SVG nodes created from the EPS/PDF file in this group
 	_xmlnode = imgnode.element.get();
 	_psi.execute(
@@ -462,7 +462,7 @@ PsSpecialHandler::ImageNode PsSpecialHandler::createPSNode (const string &fname,
 }
 
 
-PsSpecialHandler::ImageNode PsSpecialHandler::createPDFNode (const string &fname, const string &path, int pageno, BoundingBox bbox, bool clip) {
+PsSpecialHandler::ImageNode PsSpecialHandler::createPDFNode (const string &fname, const string &path, int pageno, const BoundingBox &bbox, bool clip) {
 	if (_pdfProc == "gs" || (_pdfProc.empty() && _psi.supportsPDF()))
 		return createPSNode(fname, path, pageno, bbox, clip);
 
@@ -540,8 +540,8 @@ void PsSpecialHandler::dviEndPage (unsigned, SpecialActions &actions) {
 	_previewHandler.readDataFromStack();
 	BoundingBox bbox;
 	if (_previewHandler.getBoundingBox(bbox)) {  // is there any data written by preview package?
-		double w=0, h=0, d=0;
 		if (actions.getBBoxFormatString() == "preview" || actions.getBBoxFormatString() == "min") {
+			double w=0, h=0, d=0;
 			if (actions.getBBoxFormatString() == "preview") {
 				w = max(0.0, _previewHandler.width());
 				h = max(0.0, _previewHandler.height());
@@ -952,8 +952,7 @@ void PsSpecialHandler::setpattern (vector<double> &p) {
 }
 
 
-/** Clears the current clipping path.
- *  @param[in] p not used */
+/** Clears the current clipping path. */
 void PsSpecialHandler::initclip (vector<double> &) {
 	_clipStack.pushEmptyPath();
 }
@@ -970,7 +969,6 @@ void PsSpecialHandler::clippath (std::vector<double>&) {
  *  If the graphics state already contains a clipping path, the new one is
  *  computed by intersecting the current clipping path with the current graphics
  *  path (see PS language reference, 3rd edition, pp. 193, 542)
- *  @param[in] p not used
  *  @param[in] evenodd true: use even-odd fill algorithm, false: use nonzero fill algorithm */
 void PsSpecialHandler::clip (vector<double>&, bool evenodd) {
 	clip(_path, evenodd);
@@ -1080,7 +1078,7 @@ void PsSpecialHandler::shfill (vector<double> &params) {
 		Message::estream(false) << "PostScript error: " << e.what() << '\n';
 		it.invalidate();  // stop processing the remaining patch data
 	}
-	catch (IteratorException &e) {
+	catch (IteratorException &) {
 		Message::estream(false) << "PostScript error: incomplete shading data\n";
 	}
 	if (bboxGiven)
@@ -1089,9 +1087,8 @@ void PsSpecialHandler::shfill (vector<double> &params) {
 
 
 /** Reads position and color data of a single shading patch from the data vector.
- *  @param[in] shadingTypeID PS shading type ID identifying the format of the subsequent patch data
+ *  @param[in] patch patch to be processed
  *  @param[in] edgeflag edge flag specifying how to connect the current patch to the preceding one
- *  @param[in] cspace color space used to compute the color gradient
  *  @param[in,out] it iterator used to sequentially access the patch data
  *  @param[out] points the points defining the geometry of the patch
  *  @param[out] colors the colors assigned to the vertices of the patch */
@@ -1167,7 +1164,7 @@ class ShadingCallback : public ShadingPatch::Callback {
 
 /** Handle all patch meshes whose patches and their connections can be processed sequentially.
  *  This comprises free-form triangular, Coons, and tensor-product patch meshes. */
-void PsSpecialHandler::processSequentialPatchMesh (int shadingTypeID, ColorSpace colorSpace, VectorIterator<double> &it) {
+void PsSpecialHandler::processSequentialPatchMesh (int shadingTypeID, ColorSpace colorSpace, VectorIterator<double> &it) const {
 	unique_ptr<ShadingPatch> previousPatch;
 	while (it.valid()) {
 		int edgeflag = static_cast<int>(*it++);
@@ -1197,7 +1194,7 @@ void PsSpecialHandler::processSequentialPatchMesh (int shadingTypeID, ColorSpace
 }
 
 
-void PsSpecialHandler::processLatticeTriangularPatchMesh (ColorSpace colorSpace, VectorIterator<double> &it) {
+void PsSpecialHandler::processLatticeTriangularPatchMesh (ColorSpace colorSpace, VectorIterator<double> &it) const {
 	int verticesPerRow = static_cast<int>(*it++);
 	if (verticesPerRow < 2)
 		return;
