@@ -2,7 +2,7 @@
 ** utility.hpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2025 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -236,16 +236,6 @@ struct set_const_of {
 	};
 };
 
-class Date {
-	public:
-		Date (int year, int month, int day) : _year(year), _month(month-1), _day(day-1) {}
-		bool operator < (const Date &date) const;
-		size_t operator - (Date date2) const;
-
-	private:
-		int _year, _month, _day;  // _month and _day are 0-based
-};
-
 } // namespace util
 
 #endif
